package
Version:
v0.0.0-...-ba28bb9
Opens a new window with list of versions in this module.
Published: Jul 25, 2018
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Hash struct {
Containers []string
}
Hash is a specific Image
Image is a Docker image
String returns the string representation of an Image
Source Files
¶
Click to show internal directories.
Click to hide internal directories.